@@ -1,5 +1,6 @@
 from .data import DataServer
 from .execution import ExecutionServer
+from .execution_amqp import ExecutionServerAmqp
 from .interface import InterfaceServer
 from .admin import AdminServer
-from .heap import HeapServer
\ No newline at end of file
+#from .heap import HeapServer
\ No newline at end of file
